import request from '@/utils/request'
import qs from 'qs'
import { upcloud_base_strategy,upcloud_base_wh,upcloud_base_chain  } from "@/config/serviceSettings";


export const api = {
  // queryList: baseUrl + '/item/page',
  // queryItem: baseUrl + '/item',
  addItem: upcloud_base_strategy + '/strategy/v1/add',
  updateItem: upcloud_base_strategy + '/strategy/v1/update	'
  // uploadItem: baseUrl + '/item/update',
  // deleteList: baseUrl + '/item/delete'
}

export function updateItem(parameter) {
  return request({
    method: 'post',
    url: api.updateItem,
    data: parameter
  })
}

export function addItem(parameter) {
  return request({
    method: 'post',
    url: api.addItem,
    data: parameter
  })
}

export function RuleAdd(parameter) {
  // 新增规则 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/add',
    data: parameter
  })
}

export function MainTabledel(parameter) {
  // 新增规则 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/strategy/v1/del',
    data: parameter
  })
}

//
export function MatchFactors(parameter) {
  // 查询匹配因子 GET
  return request({
    method: 'get',
    url: upcloud_base_strategy + '/rule/v1/match-factors',
    data: parameter
  })
}
export function SearchFactors(parameter) {
  // 查询搜索因子 GET
  return request({
    method: 'get',
    url: upcloud_base_strategy + '/rule/v1/search-factors',
    data: parameter
  })
}

export function FactorAdd(parameter) {
  // 查询搜索因子 GET
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/factor/add',
    data: parameter
  })
}
//
export function FactorDel(parameter) {
  // 查询搜索因子 GET
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/factor/del',
    data: parameter
  })
}

//   /rule/v1/algorithm
export function Algorithm(parameter) {
  // 查询算法 GET
  return request({
    method: 'get',
    url: upcloud_base_strategy + '/rule/v1/algorithm',
    data: parameter
  })
}

//   /rule/v1/algorithm/add
export function AlgorithmAdd(parameter) {
  //  添加规则算法 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/algorithm/add',
    data: parameter
  })
}

//   AlgorithmDel

export function AlgorithmDel(parameter) {
  //  添加规则算法 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/algorithm/del',
    data: parameter
  })
}

// /rule/v1/info/update

export function InfoUpdate(parameter) {
  //  添加规则算法 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/info/update',
    data: parameter
  })
}

//   /rule/v1/del

export function RuleDel(parameter) {
  //  添加规则算法 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/del',
    data: parameter
  })
}

//
export function AlgorithmUp(parameter) {
  //   上移规则算法 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/algorithm/up/update',
    data: parameter
  })
}
export function AlgorithmDown(parameter) {
  //   下移规则算法 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/algorithm/down/update',
    data: parameter
  })
}

export function RuleDisableUpdate(parameter) {
  //   下移规则算法 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/disable/update',
    data: parameter
  })
}

export function StrategyEnableUpdate(parameter) {
  //    启用策略 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/strategy/v1/enable/update',
    data: parameter
  })
}

export function RuleDown(parameter) {
  //     下移规则 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/down/update',
    data: parameter
  })
}
export function RuleUp(parameter) {
  //     上移规则 POST
  return request({
    method: 'post',
    url: upcloud_base_strategy + '/rule/v1/up/update',
    data: parameter
  })
}

export function getWarehouseInfo(parameter) {
  // 新增规则 POST
  return request({
    method: 'get',
    url: upcloud_base_wh+'/warehouse/basic/list',
    params: parameter
  })
}
export function getCargoOwnerInfo(parameter) {
  // 新增规则 POST
  return request({
    method: 'post',
    url: upcloud_base_chain+'/baseCargoOwnerMst/v1.0/getByIds',
    data: parameter
  })
}
// /rule/v1/down/update
